@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 from collections import defaultdict
-from collections.abc import Iterable
+from collections.abc import Iterable, Sequence
 from pathlib import Path
 from typing import Generic
 
@@ -28,12 +28,11 @@ from rich.console import Console
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.exceptions import ToolkitNotImplementedError
 from cognite_toolkit._cdf_tk.loaders import AssetLoader, DataSetsLoader, FileMetadataLoader, LabelLoader, ResourceLoader
-from cognite_toolkit._cdf_tk.loaders._base_loaders import T_ID, T_WritableCogniteResourceList
 from cognite_toolkit._cdf_tk.utils.aggregators import AssetAggregator, AssetCentricAggregator, FileAggregator
 from cognite_toolkit._cdf_tk.utils.cdf import metadata_key_counts
 from cognite_toolkit._cdf_tk.utils.file import find_files_with_suffix_and_prefix
 from cognite_toolkit._cdf_tk.utils.fileio import SchemaColumn
-from cognite_toolkit._cdf_tk.utils.useful_types import JsonVal
+from cognite_toolkit._cdf_tk.utils.useful_types import T_ID, JsonVal, T_WritableCogniteResourceList
 
 from ._base import StorageIOConfig, TableStorageIO
 from ._selectors import AssetCentricFileSelector, AssetCentricSelector, AssetSubtreeSelector, DataSetSelector
@@ -41,7 +40,7 @@ from ._selectors import AssetCentricFileSelector, AssetCentricSelector, AssetSub
 
 class BaseAssetCentricIO(
     Generic[T_ID, T_WriteClass, T_WritableCogniteResource, T_CogniteResourceList, T_WritableCogniteResourceList],
-    TableStorageIO[AssetCentricSelector, T_CogniteResourceList, T_WritableCogniteResourceList],
+    TableStorageIO[int, AssetCentricSelector, T_CogniteResourceList, T_WritableCogniteResourceList],
     ABC,
 ):
     chunk_size = 1000
@@ -53,6 +52,12 @@ class BaseAssetCentricIO(
         self._downloaded_data_sets_by_selector: dict[AssetCentricSelector, set[int]] = defaultdict(set)
         self._downloaded_labels_by_selector: dict[AssetCentricSelector, set[str]] = defaultdict(set)
 
+    def as_id(self, item: dict[str, JsonVal] | object) -> int:
+        if isinstance(item, dict) and isinstance(item.get("id"), int):
+            # MyPy checked above.
+            return item["id"]  # type: ignore[return-value]
+        raise TypeError(f"Cannot extract ID from item of type {type(item).__name__!r}")
+
     @abstractmethod
     def _get_loader(
         self,
@@ -65,6 +70,10 @@ class BaseAssetCentricIO(
     def _get_aggregator(self) -> AssetCentricAggregator:
         raise NotImplementedError()
 
+    @abstractmethod
+    def retrieve(self, ids: Sequence[int]) -> T_WritableCogniteResourceList:
+        raise NotImplementedError()
+
     def count(self, selector: AssetCentricSelector) -> int | None:
         if isinstance(selector, DataSetSelector):
             return self._aggregator.count(data_set_external_id=selector.data_set_external_id)
@@ -164,6 +173,11 @@ class AssetIO(BaseAssetCentricIO[str, AssetWrite, Asset, AssetWriteList, AssetLi
     supported_compressions = frozenset({".gz"})
     supported_read_formats = frozenset({".parquet", ".csv", ".ndjson", ".yaml", ".yml"})
 
+    def as_id(self, item: dict[str, JsonVal] | object) -> int:
+        if isinstance(item, Asset | AssetWrite) and item.id is not None:  # type: ignore[union-attr]
+            return item.id  # type: ignore[union-attr]
+        return super().as_id(item)
+
     def _get_loader(self) -> AssetLoader:
         return AssetLoader.create_loader(self.client)
 
@@ -228,6 +242,9 @@ class AssetIO(BaseAssetCentricIO[str, AssetWrite, Asset, AssetWriteList, AssetLi
     def json_chunk_to_data(self, data_chunk: list[dict[str, JsonVal]]) -> AssetWriteList:
         return AssetWriteList([self._loader.load_resource(item) for item in data_chunk])
 
+    def retrieve(self, ids: Sequence[int]) -> AssetList:
+        return self.client.assets.retrieve_multiple(ids)
+
 
 class FileMetadataIO(BaseAssetCentricIO[str, FileMetadataWrite, FileMetadata, FileMetadataWriteList, FileMetadataList]):
     folder_name = FileMetadataLoader.folder_name
@@ -237,6 +254,11 @@ class FileMetadataIO(BaseAssetCentricIO[str, FileMetadataWrite, FileMetadata, Fi
     supported_compressions = frozenset({".gz"})
     supported_read_formats = frozenset({".parquet", ".csv", ".ndjson"})
 
+    def as_id(self, item: dict[str, JsonVal] | object) -> int:
+        if isinstance(item, FileMetadata | FileMetadataWrite) and item.id is not None:  # type: ignore[union-attr]
+            return item.id  # type: ignore[union-attr]
+        return super().as_id(item)
+
     def _get_loader(self) -> FileMetadataLoader:
         return FileMetadataLoader.create_loader(self.client)
 
@@ -294,6 +316,9 @@ class FileMetadataIO(BaseAssetCentricIO[str, FileMetadataWrite, FileMetadata, Fi
             self._collect_dependencies(file_list, selector)
             yield file_list
 
+    def retrieve(self, ids: Sequence[int]) -> FileMetadataList:
+        return self.client.files.retrieve_multiple(ids)
+
     def upload_items(self, data_chunk: FileMetadataWriteList, selector: AssetCentricSelector) -> None:
         if not data_chunk:
             return
